@@ -22,11 +22,11 @@ VSGDR::StaticData - Static data script support package for SSDT post-deployment
 
 =head1 VERSION
 
-Version 0.27
+Version 0.28
 
 =cut
 
-our $VERSION = '0.27';
+our $VERSION = '0.28';
 
 
 sub databaseName {
@@ -506,9 +506,10 @@ begin catch
     -- If our transaction is the only one, then just rollback.
     if \@\@trancount > 0 begin
         if \@\@trancount > 1 begin
-            if \@localTransactionStarted is not null and \@localTransactionStarted = 1 
+            if \@localTransactionStarted is not null and \@localTransactionStarted = 1 begin
                 rollback transaction ${savePointName};
                 commit ; --  windback our local transaction completely
+			end
             --else it's probably nothing to do with us.
         end
             else rollback
